__all__ = [
    'MajorityVote',
]
import crowdkit.aggregation.base
import pandas.core.frame
import pandas.core.series
import typing


class MajorityVote(crowdkit.aggregation.base.BaseClassificationAggregator):
    """Majority Vote - chooses the correct label for which more performers voted
    Attributes:
        labels_ (typing.Optional[pandas.core.series.Series]): Tasks' labels
            A pandas.Series indexed by `task` such that `labels.loc[task]`
            is the tasks's most likely true label.

        skills_ (typing.Optional[pandas.core.series.Series]): Performers' skills
            A pandas.Series index by performers and holding corresponding performer's skill
        probas_ (typing.Optional[pandas.core.frame.DataFrame]): Tasks' label probability distributions
            A pandas.DataFrame indexed by `task` such that `result.loc[task, label]`
            is the probability of `task`'s true label to be equal to `label`. Each
            probability is between 0 and 1, all task's probabilities should sum up to 1

        on_missing_skill (str): How to handle assignments done by workers with unknown skill
            Possible values:
                    * "error" — raise an exception if there is at least one assignment done by user with unknown skill;
                    * "ignore" — drop assignments with unknown skill values during prediction. Raise an exception if there is no 
                    assignments with known skill for any task;
                    * value — default value will be used if skill is missing.
    """

    def fit(
        self,
        data: pandas.core.frame.DataFrame,
        skills: pandas.core.series.Series = None
    ) -> 'MajorityVote':
        """Args:
            data (DataFrame): Performers' labeling results
                A pandas.DataFrame containing `task`, `performer` and `label` columns.
            skills (Series): Performers' skills
                A pandas.Series index by performers and holding corresponding performer's skill
        Returns:
            MajorityVote: self
        """
        ...

    def fit_predict_proba(
        self,
        data: pandas.core.frame.DataFrame,
        skills: pandas.core.series.Series = None
    ) -> pandas.core.frame.DataFrame:
        """Args:
            data (DataFrame): Performers' labeling results
                A pandas.DataFrame containing `task`, `performer` and `label` columns.
            skills (Series): Performers' skills
                A pandas.Series index by performers and holding corresponding performer's skill
        Returns:
            DataFrame: Tasks' label probability distributions
                A pandas.DataFrame indexed by `task` such that `result.loc[task, label]`
                is the probability of `task`'s true label to be equal to `label`. Each
                probability is between 0 and 1, all task's probabilities should sum up to 1
        """
        ...

    def fit_predict(
        self,
        data: pandas.core.frame.DataFrame,
        skills: pandas.core.series.Series = None
    ) -> pandas.core.series.Series:
        """Args:
            data (DataFrame): Performers' labeling results
                A pandas.DataFrame containing `task`, `performer` and `label` columns.
            skills (Series): Performers' skills
                A pandas.Series index by performers and holding corresponding performer's skill
        Returns:
            Series: Tasks' labels
                A pandas.Series indexed by `task` such that `labels.loc[task]`
                is the tasks's most likely true label.
        """
        ...

    def __init__(
        self,
        on_missing_skill: str = 'error',
        default_skill: typing.Optional[float] = None
    ) -> None:
        """Method generated by attrs for class MajorityVote.
        """
        ...

    labels_: typing.Optional[pandas.core.series.Series]
    skills_: typing.Optional[pandas.core.series.Series]
    probas_: typing.Optional[pandas.core.frame.DataFrame]
    on_missing_skill: str
    default_skill: typing.Optional[float]
